@@ -2,12 +2,13 @@ package Mojo::SQLite::Migrations;
 use Mojo::Base -base;
 
 use Carp 'croak';
+use Mojo::File 'path';
 use Mojo::Loader 'data_section';
-use Mojo::Util qw(decode slurp);
+use Mojo::Util 'decode';
 
 use constant DEBUG => $ENV{MOJO_MIGRATIONS_DEBUG} || 0;
 
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 has name => 'migrations';
 has 'sqlite';
@@ -20,7 +21,7 @@ sub from_data {
     data_section($class //= caller, $name // $self->name));
 }
 
-sub from_file { shift->from_string(decode 'UTF-8', slurp pop) }
+sub from_file { shift->from_string(decode 'UTF-8', path(pop)->slurp) }
 
 sub from_string {
   my ($self, $sql) = @_;
